@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : REM
-Version : 1.0.5
+Version : 1.0.8
 Author  : Stefano Covino
-Date    : 18/04/2012
+Date    : 29/08/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -19,9 +19,12 @@ History : (16/12/2011) First version.
         : (01/04/2012) V. 1.1.1b1.
         : (04/04/2012) V. 1.2.0b1 and new constant.
         : (18/04/2012) V. 1.2.0.
+        : (01/08/2012) V. 1.2.1b1.
+        : (22/08/2012) V. 1.3.0b1.
+        : (29/08/2012) V. 1.3.0.
 """
 
-__version__ = '1.2.0'
+__version__ = '1.3.0'
 
 
 
